===============
 ``zope.site``
===============

.. image:: https://img.shields.io/pypi/v/zope.site.svg
        :target: https://pypi.python.org/pypi/zope.site/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.site.svg
        :target: https://pypi.org/project/zope.site/
        :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/zope.site/workflows/tests/badge.svg
   :target: https://github.com/zopefoundation/zope.site/actions?query=workflow%3Atests

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.site/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.site?branch=master

.. image:: https://readthedocs.org/projects/zopesite/badge/?version=latest
        :target: httpl://zopesite.readthedocs.io/en/latest/
        :alt: Documentation Status


This package provides a local and persistent site manager
implementation, so that one can register local utilities and
adapters. It uses local adapter registries for its adapter and utility
registry. The module also provides some facilities to organize the
local software and ensures the correct behavior inside the ZODB.

Documentation is hosted at https://zopesite.readthedocs.io
